%define name dante
%define version 1.1.11
%define release 2mdk
%define prefix %{_prefix}

Summary: A free Socks v4/v5 client implementation
Name: dante
Version: %{version}
Release: %{release}
License: BSD-like
Group: Networking/Other
URL: http://www.inet.no/dante/
Source: %{name}-%{version}.tar.bz2
Buildroot: %{_tmppath}/%{name}-buildroot
Buildrequires: perl-base

%description
Dante is a free implementation of the proxy protocols socks version 4,
socks version 5 (rfc1928) and msproxy. It can be used as a firewall
between networks. It is being developed by Inferno Nettverk A/S, a
Norwegian consulting company. Commercial support is available.

This package contains the dynamic libraries required to "socksify"
existing applications to become socks clients.

%package server
Summary: A free Socks v4/v5 server implementation
Group: System/Servers
Requires: dante = %{version}

%description server
This package contains the socks proxy daemon and its documentation.
The sockd is the server part of the Dante socks proxy package and
allows socks clients to connect through it to the network.

%package devel
Summary: Development libraries for socks
Group: Development/Other
Requires: dante = %{version}

%description devel
Additional libraries required to compile programs that use socks.

%prep
rm -rf $RPM_BUILD_ROOT

%setup -n %name-%version

# This file is embedded here instead of being another source in order
# to the prefix directory
cat >sockd.init <<EOF
#!/bin/sh
#
# sockd         This shell script takes care of starting and stopping
#               the Dante server.
#
# chkconfig: 2345 65 35
# description: sockd implements a socks v4/v5 proxy server

# Source function library.
. /etc/rc.d/init.d/functions

# Source networking configuration.
. /etc/sysconfig/network

# Check that networking is up.
[ \${NETWORKING} = "no" ] && exit 0

[ -f /usr/sbin/sockd ] || exit 0

[ ! -f /etc/sockd.conf ] && exit 1
SOCKD_CONF="-f /etc/sockd.conf"

# See how we were called.
case "\$1" in
  start)
	# Start daemons.
	echo -n "Starting sockd: "
	daemon /usr/sbin/sockd -D \$SOCKD_CONF
	echo
	touch /var/lock/subsys/sockd
	;;
  stop)
	# Stop daemons.
	echo -n "Shutting down sockd: "
	killproc sockd
	echo
	rm -f /var/lock/subsys/sockd
	;;
  restart)
	\$0 stop
	\$0 start
	;;
  status)
	status sockd
	;;
  *)
	echo "Usage: sockd {start|stop|restart|status}"
	exit 1
esac

exit 0
EOF

%build

%configure

%make

%install
rm -rf ${RPM_BUILD_ROOT}

%makeinstall

#set library as executable - prevent ldd from complaining
chmod +x ${RPM_BUILD_ROOT}%{prefix}/lib/*.so.*.*

install -d ${RPM_BUILD_ROOT}/etc/rc.d/init.d ${RPM_BUILD_ROOT}%{prefix}/bin

install -m 644 example/socks.conf ${RPM_BUILD_ROOT}/etc
install -m 644 example/sockd.conf ${RPM_BUILD_ROOT}/etc

install -m 755 sockd.init ${RPM_BUILD_ROOT}/etc/rc.d/init.d/sockd

ln -sf %{prefix}/lib/libdsocks.so $RPM_BUILD_ROOT/%{prefix}/lib/libdsocks.so.0
ln -sf %{prefix}/lib/libdsocks.so.0 $RPM_BUILD_ROOT/%{prefix}/lib/libdsocks.so

# lenny : 	remove cause it conflicts with glibc-devel
# 		a strace shows that a call is done to libdl.so
#ln -sf %{prefix}/lib/libdl.so.2 $RPM_BUILD_ROOT/%{prefix}/lib/libdl.so

# bor: add explicit versions to libraries
/usr/bin/perl -pe 's/(libdl\.so)/$1.2/;s/(libdsocks\.so)/$1.0/' -i ${RPM_BUILD_ROOT}/${prefix}/bin/socksify


%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post server
/sbin/chkconfig --add sockd

%postun server
if [ $1 = 0 ]; then
   /sbin/chkconfig --del sockd
fi

%files
%defattr(-,root,root)
%doc [A-Z][A-Z]*
%_libdir/*.so.*
%_bindir/socksify
%_mandir/man5/socks.conf.5*
%config(noreplace) /etc/socks.conf

%files server
%defattr(-,root,root)
%_sbindir/sockd
%_mandir/man5/sockd.conf.5*
%_mandir/man8/*
%config(noreplace) /etc/sockd.conf
%config(noreplace)  /etc/rc.d/init.d/sockd

%files devel
%defattr (-,root,root)
%_libdir/*.la
%_libdir/*.a
%_libdir/*.so

%changelog
* Wed Feb 06 2002 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-2mdk
- patch from Borsenkow Andrej <Andrej.Borsenkow@mow.siemens.ru> :
	o add explicit versions to libraries	

* Tue Feb 05 2002 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-1mdk
- update to 1.1.11 final
- again fix in initscript 
  ( thx Borsenkow Andrej <Andrej.Borsenkow@mow.siemens.ru>)

* Tue Feb 05 2002 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-0.4mdk
- fixes initscript from Pascal Terjan <pascal.terjan@free.fr>

* Sat Nov 24 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-0.3mdk
- minor changes in initscript to be sure to use /etc/sockd.conf
- remove libdl for now
- some spec cleaning

* Fri Nov 23 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-0.2mdk
- 1.1.11pre2

* Tue Nov 13 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-0.1mdk
- 1.1.11pre1

* Wed Sep 05 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.10-2mdk
- links libdsocks.so.0, libdl.so.2, thx Thomas Poindessous

* Mon Jul 02 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.10-1mdk
- upgraded to 1.1.10

* Wed Mar 14 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.9-1mdk
- updated to 1.1.9

* Thu Feb 22 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.8-1mdk
- updated to 1.1.8

* Mon Jan 08 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.6-1mdk
- updated to 1.1.6
- rebuild

* Tue Jun 13 2000 Lenny Cartier <lenny@mandrakesoft.com> 1.1.1-2mdk
- fix link on libdsocks

* Thu Jun 10 2000 Geoffrey Lee <snailtalk@linux-mandrake.com> 1.1.1-1mdk
- mandrake adaptations
- first release for mandrake

* Wed Mar 10 1999 Karl-Andre' Skevik <karls@inet.no>
- Integrated into CVS
- socksify patch no longer needed

* Thu Mar 04 1999 Oren Tirosh <oren@hishome.net>
- configurable %{prefix}, fixed daemon init script
- added /lib/libdl.so to socksify

* Wed Mar 03 1999 Oren Tirosh <oren@hishome.net>
- First spec file for Dante
